from __future__ import annotations
from msgspec import Struct, field
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from msgspec_schemaorg.models.action.Action import Action
    from msgspec_schemaorg.models.creativework.CreativeWork import CreativeWork
    from msgspec_schemaorg.models.creativework.ImageObject import ImageObject
    from msgspec_schemaorg.models.creativework.TextObject import TextObject
    from msgspec_schemaorg.models.event.Event import Event
    from msgspec_schemaorg.models.intangible.EUEnergyEfficiencyEnumeration import EUEnergyEfficiencyEnumeration
    from msgspec_schemaorg.models.intangible.EnergyEfficiencyEnumeration import EnergyEfficiencyEnumeration
    from msgspec_schemaorg.models.intangible.PropertyValue import PropertyValue


class EnergyConsumptionDetails(Struct, frozen=True):
    """EnergyConsumptionDetails represents information related to the energy efficiency of a product that consumes energy. The information that can be provided is based on international regulations such as for example [EU directive 2017/1369](https://eur-lex.europa.eu/eli/reg/2017/1369/oj) for energy labeling and the [Energy labeling rule](https://www.ftc.gov/enforcement/rules/rulemaking-regulatory-reform-proceedings/energy-water-use-labeling-consumer) under the Energy Policy and Conservation Act (EPCA) in the US."""
    name: str | None = None
    mainEntityOfPage: str | 'CreativeWork' | None = None
    url: str | None = None
    disambiguatingDescription: str | None = None
    identifier: str | 'PropertyValue' | str | None = None
    description: str | 'TextObject' | None = None
    subjectOf: 'Event' | 'CreativeWork' | None = None
    alternateName: str | None = None
    additionalType: str | str | None = None
    potentialAction: 'Action' | None = None
    sameAs: str | None = None
    image: 'ImageObject' | str | None = None
    hasEnergyEfficiencyCategory: 'EnergyEfficiencyEnumeration' | None = None
    energyEfficiencyScaleMin: 'EUEnergyEfficiencyEnumeration' | None = None
    energyEfficiencyScaleMax: 'EUEnergyEfficiencyEnumeration' | None = None